/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 * $Id: LoginServices.java,v 1.5 2003/02/03 21:47:47 jacobk Exp $
 */
package org.enhydra.barracuda.discRack.pres.services;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;

import org.enhydra.barracuda.core.event.*;
import org.enhydra.barracuda.plankton.data.*;
import org.enhydra.barracuda.core.util.http.*;

import org.enhydra.barracuda.discRack.biz.person.Person;

/**
 * This class provides basic Login services. You can see whether
 * the user is logged in, get the current user (Person), log them in
 * or out.
 */
public class LoginServices {

	//private constants
	private static String PERSON = LoginServices.class.getName()+".Person";

	/**
	 * See if the current user is actually logged in
	 */
	public static boolean isLoggedIn(HttpSession session) {
//Debug.println (new LoginServices(),0,"isLoggedIn:"+session.getAttribute(PERSON));
		return (session.getAttribute(PERSON)!=null);
	}

	/**
	 * Get the Person record for the current user
	 */
	public static Person getCurrentUser(HttpSession session) {
		return (Person) session.getAttribute(PERSON);
	}

	/**
	 * Actually log a user in by storing the Person account in the
	 * session
	 */
	public static void logIn(HttpSession session, Person person) {
//Debug.println (new LoginServices(),0,"logging in:"+person);
		session.setAttribute(PERSON, person);
	}

	/**
	 * Actually log a user out by removing the Person account from the
	 * session
	 */
	public static void logOut(HttpSession session) {
//Debug.println (new LoginServices(),0,"logging out");
		session.removeAttribute(PERSON);
	}
}
